@@ -12,8 +12,6 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-import socket
-
 import httplib2
 import json
 
@@ -32,7 +30,6 @@ from networking_bagpipe.bagpipe_bgp import constants as bbgp_const
 
 from neutron.conf.agent import common as config
 
-from neutron_lib import constants as n_const
 from neutron_lib import exceptions as n_exc
 
 LOG = logging.getLogger(__name__)
@@ -82,7 +79,7 @@ class SetJSONEncoder(jsonutils.JSONEncoder):
         return json.JSONEncoder.default(self, obj)
 
 
-class HTTPClientBase(object):
+class HTTPClientBase:
     """An HTTP client base class"""
 
     def __init__(self, host="127.0.0.1", port=8082,
@@ -107,7 +104,7 @@ class HTTPClientBase(object):
             headers = {'User-Agent': self.client_name,
                        "Content-Type": "application/json",
                        "Accept": "application/json"}
-            uri = "http://%s:%s/%s" % (self.host, self.port, action)
+            uri = "http://{}:{}/{}".format(self.host, self.port, action)
 
             http = httplib2.Http()
             response, content = http.request(uri, method, body, headers)
@@ -122,7 +119,7 @@ class HTTPClientBase(object):
                     "An HTTP operation has failed on bagpipe-bgp."
                 )
                 raise BaGPipeBGPException(reason=reason)
-        except (socket.error, IOError) as e:
+        except OSError as e:
             reason = "Failed to connect to bagpipe-bgp: %s" % str(e)
             raise BaGPipeBGPException(reason=reason)
 
@@ -140,7 +137,7 @@ class HTTPClientBase(object):
 
 
 def get_default_vpn_instance_id(vpn_type, network_id):
-    return '%s_%s' % (vpn_type, network_id)
+    return '{}_{}'.format(vpn_type, network_id)
 
 
 class BaGPipeBGPAgent(HTTPClientBase):
@@ -184,9 +181,8 @@ class BaGPipeBGPAgent(HTTPClientBase):
         :param agent_type: bagpipe-bgp agent type (Linux bridge or OVS)
 
         """
-        super(BaGPipeBGPAgent,
-              self).__init__(cfg.CONF.BAGPIPE.bagpipe_bgp_ip,
-                             cfg.CONF.BAGPIPE.bagpipe_bgp_port, agent_type)
+        super().__init__(cfg.CONF.BAGPIPE.bagpipe_bgp_ip,
+                         cfg.CONF.BAGPIPE.bagpipe_bgp_port, agent_type)
 
         self.agent_type = agent_type
 
@@ -290,13 +286,6 @@ class BaGPipeBGPAgent(HTTPClientBase):
         # attributes accumulate the RTs of all the service producing
         # attachments for a given VPN instance (vpn instance id).
         #
-        # Another consolidation that is done in the case where both EVPN and
-        # IPVPN attachments are produced, and the agent is a linuxbridge agent.
-        # In that case the IPVPN attachments are modified so that instead of
-        # plugging the port into the IPVPN, the EVPN instance is plugged into
-        # the IPVPN, which is necessary so that bagpipe-bgp will connect the
-        # linux bridge to a linux VRF with a veth interface.
-        #
         # NOTE(tmorin): the code does not do consistency checks for parameters
         # that would be conflicting between attachments, for instance if
         # an EVPN attachment would specify a VNI X and another a VNI Y.
@@ -402,18 +391,6 @@ class BaGPipeBGPAgent(HTTPClientBase):
             if vpn_attachment_list:
                 attach_list[vpn_type] = vpn_attachment_list
 
-        if self.agent_type == n_const.AGENT_TYPE_LINUXBRIDGE:
-            if (attach_list.get(bbgp_const.EVPN) and
-                    attach_list.get(bbgp_const.IPVPN)):
-                # go through all IPVPN attachments and rewrite local_port
-                # to point to the evpn instance, rather than the VM port
-                for attachment in attach_list[bbgp_const.IPVPN]:
-                    attachment['local_port'] = {bbgp_const.EVPN: {
-                        'id': attachment['vpn_instance_id'].replace('ipvpn',
-                                                                    'evpn')
-                        }
-                    }
-
         LOG.debug("all attachments for port %s: %s", port_id, attach_list)
         return attach_list
 
