@@ -1,6 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-# encoding: utf-8
-
 # Copyright 2014 Orange
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -61,7 +58,7 @@ def proxy_arp(ifname, enable):
 class MPLSLinuxVRFDataplane(dp_drivers.VPNInstanceDataplane):
 
     def __init__(self, *args, **kwargs):
-        super(MPLSLinuxVRFDataplane, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
         # FIXME: maybe not thread safe ?
         self.ip = self.driver.ip
@@ -164,8 +161,8 @@ class MPLSLinuxVRFDataplane(dp_drivers.VPNInstanceDataplane):
         # Configure gateway address on this port
         # FIXME: that would need to be per vif port
         # Retrieve broadcast IP address
-        broadcast_ip = str(netaddr.IPNetwork("%s/%s" % (self.gateway_ip,
-                                                        self.network_plen)
+        broadcast_ip = str(netaddr.IPNetwork("{}/{}".format(self.gateway_ip,
+                                                            self.network_plen)
                                              ).broadcast)
 
         try:
@@ -224,7 +221,8 @@ class MPLSLinuxVRFDataplane(dp_drivers.VPNInstanceDataplane):
         # Unconfigure gateway address on this port
         # FIXME: that would need to be per vif port
         # Retrieve broadcast IP address
-        ip = netaddr.IPNetwork("%s/%s" % (self.gateway_ip, self.network_plen))
+        ip = netaddr.IPNetwork(
+            "{}/{}".format(self.gateway_ip, self.network_plen))
         broadcast_ip = str(ip.broadcast)
 
         ipr.addr('del', index=self.ip.interfaces[interface].index,
@@ -354,7 +352,7 @@ class MPLSLinuxDataplaneDriver(dp_drivers.DataplaneDriver):
     ]
 
     def __init__(self):
-        super(MPLSLinuxDataplaneDriver, self).__init__()
+        super().__init__()
 
         privileged_utils.modprobe('mpls_router')
         privileged_utils.modprobe('mpls_gso')
@@ -384,7 +382,7 @@ class MPLSLinuxDataplaneDriver(dp_drivers.DataplaneDriver):
 
     @log_decorator.log_info
     def initialize(self):
-        sysctl('net.mpls.platform_labels', 2**20-1)
+        sysctl('net.mpls.platform_labels', 2 ** 20 - 1)
 
         if "*gre*" in self.config["mpls_interface"]:
             self.mpls_interface = "gre_wildcard"
