@@ -1,6 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-# encoding: utf-8
-
 # Copyright 2014 Orange
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -18,11 +15,11 @@
 import re
 
 import collections
-from distutils import version  # pylint: disable=no-name-in-module
 import netaddr
 from oslo_config import cfg
 from oslo_config import types
 from oslo_log import log as logging
+from oslo_utils import versionutils
 
 from neutron.common import utils as n_utils
 
@@ -39,8 +36,8 @@ from networking_bagpipe.bagpipe_bgp.vpn import identifier_allocators
 from networking_bagpipe.bagpipe_bgp.vpn import vpn_instance
 
 from neutron.agent.common import ovs_lib
-from neutron.plugins.ml2.drivers.openvswitch.agent.common import \
-    constants as ovs_const
+
+from neutron_lib.plugins.ml2 import ovs_constants as ovs_const
 
 # man ovs-ofctl /32768
 DEFAULT_OVS_FLOW_PRIORITY = 0x8000
@@ -115,7 +112,7 @@ def _priority_from_prefix(prefix):
 class MPLSOVSVRFDataplane(dp_drivers.VPNInstanceDataplane):
 
     def __init__(self, *args, **kwargs):
-        super(MPLSOVSVRFDataplane, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
         # Initialize dict where we store info on OVS ports (port numbers and
         # bound IP address)
@@ -212,7 +209,7 @@ class MPLSOVSVRFDataplane(dp_drivers.VPNInstanceDataplane):
         if exit_code != 0:
             self.log.warning("No %s if, not trying to fix MTU", itf)
         else:
-            self._run_command("ip link set %s mtu %s" % (itf, mtu),
+            self._run_command("ip link set {} mtu {}".format(itf, mtu),
                               run_as_root=True)
 
     def _get_ovs_port_specifics(self, localport):
@@ -385,8 +382,9 @@ class MPLSOVSVRFDataplane(dp_drivers.VPNInstanceDataplane):
         if vpn_instance.forward_to_port(direction):
             # Map incoming MPLS traffic going to the VM port
             incoming_actions = [self.get_push_vlan_action(),
-                                "mod_dl_src:%s,mod_dl_dst:%s" % (GATEWAY_MAC,
-                                                                 mac_address),
+                                "mod_dl_src:{},mod_dl_dst:{}".format(
+                                    GATEWAY_MAC,
+                                    mac_address),
                                 "output:%s" % ovs_port]
 
             self.bridge.add_flow_extended(
@@ -486,11 +484,11 @@ class MPLSOVSVRFDataplane(dp_drivers.VPNInstanceDataplane):
             if (self.driver.vxlan_encap and
                     exa.Encapsulation(exa.Encapsulation.Type.VXLAN) in encaps):
                 self.log.debug("Will use a VXLAN encap for this destination")
-                return "set_field:%s->tun_dst,output:%s" % (
+                return "set_field:{}->tun_dst,output:{}".format(
                     remote_pe, self.driver.vxlan_tunnel_port_number)
             elif self.driver.use_gre:
                 self.log.debug("Using MPLS/GRE encap")
-                return "set_field:%s->tun_dst,output:%s" % (
+                return "set_field:{}->tun_dst,output:{}".format(
                     remote_pe, self.driver.gre_tunnel_port_number)
             else:
                 self.log.debug("Using bare MPLS encap")
@@ -508,7 +506,7 @@ class MPLSOVSVRFDataplane(dp_drivers.VPNInstanceDataplane):
 
                 # Map traffic to remote IP address as MPLS on ethX to remote
                 # router MAC address
-                return "mod_dl_src:%s,mod_dl_dst:%s,output:%s" % (
+                return "mod_dl_src:{},mod_dl_dst:{},output:{}".format(
                     self.driver.mpls_if_mac_address, remote_pe_mac_address,
                     self.driver.ovs_mpls_if_port_number)
 
@@ -533,7 +531,7 @@ class MPLSOVSVRFDataplane(dp_drivers.VPNInstanceDataplane):
             return
 
         dec_ttl = (netaddr.IPNetwork(prefix) not in netaddr.IPNetwork(
-                   "%s/%s" % (self.gateway_ip, self.network_plen)))
+                   "{}/{}".format(self.gateway_ip, self.network_plen)))
         label_action = self._get_label_action(nexthop.label,
                                               nexthop.encaps)
         output_action = self._get_output_action(nexthop.remote_pe,
@@ -559,7 +557,7 @@ class MPLSOVSVRFDataplane(dp_drivers.VPNInstanceDataplane):
 
     def _get_port_range_from_classifier(self, classifier_port):
         if classifier_port:
-            if type(classifier_port) == tuple:
+            if isinstance(classifier_port, tuple):
                 port_min, port_max = classifier_port
             else:
                 port_min = port_max = classifier_port
@@ -568,18 +566,18 @@ class MPLSOVSVRFDataplane(dp_drivers.VPNInstanceDataplane):
 
     def _create_port_range_flow_matches(self, classifier_match, classifier):
         flow_matches = []
-        src_port_match = '{:s}_src'.format(classifier.protocol)
+        src_port_match = f'{classifier.protocol:s}_src'
 
         if classifier.source_port:
-            if type(classifier.source_port) == tuple:
+            if isinstance(classifier.source_port, tuple):
                 src_port_min, src_port_max = classifier.source_port
             else:
                 src_port_min = src_port_max = classifier.source_port
 
-        dst_port_match = '{:s}_dst'.format(classifier.protocol)
+        dst_port_match = f'{classifier.protocol:s}_dst'
 
         if classifier.destination_port:
-            if type(classifier.destination_port) == tuple:
+            if isinstance(classifier.destination_port, tuple):
                 dst_port_min, dst_port_max = classifier.destination_port
             else:
                 dst_port_min = dst_port_max = classifier.destination_port
@@ -663,16 +661,16 @@ class MPLSOVSVRFDataplane(dp_drivers.VPNInstanceDataplane):
 
 class OVSGroupAllocator(identifier_allocators.IDAllocator):
 
-    MAX = 2**32-1
+    MAX = 2 ** 32 - 1
 
 
 class OVSBucketAllocator(identifier_allocators.IDAllocator):
 
     # Values greater than 0xFFFFFF00 are reserved
-    MAX = 2**32-2**8-1
+    MAX = 2 ** 32 - 2 ** 8 - 1
 
 
-class NextHop(object):
+class NextHop:
 
     def __init__(self, label, remote_pe, encaps, lb_consistent_hash_order):
         self.label = label
@@ -690,16 +688,16 @@ class NextHop(object):
                      self.encaps))
 
     def __repr__(self):
-        return "NextHop(%s,%s,%s,%s)" % (self.label,
-                                         self.remote_pe,
-                                         self.encaps,
-                                         self.lb_consistent_hash_order)
+        return "NextHop({},{},{},{})".format(self.label,
+                                             self.remote_pe,
+                                             self.encaps,
+                                             self.lb_consistent_hash_order)
 
 
 class NextHopGroupManager(dataplane_utils.ObjectLifecycleManager):
 
     def __init__(self, bridge, hash_method, hash_method_param, hash_fields):
-        super(NextHopGroupManager, self).__init__()
+        super().__init__()
 
         self.bridge = bridge
         self.hash_method = hash_method
@@ -741,7 +739,7 @@ class NextHopGroupManager(dataplane_utils.ObjectLifecycleManager):
 class NextHopGroupManagerProxy(dataplane_utils.ObjectLifecycleManagerProxy):
 
     def __init__(self, manager, parent_key, vrf_table, vrf_match, cookie_func):
-        super(NextHopGroupManagerProxy, self).__init__(manager, parent_key)
+        super().__init__(manager, parent_key)
 
         self.vrf_table = vrf_table
         self.vrf_match = vrf_match
@@ -772,7 +770,8 @@ class NextHopGroupManagerProxy(dataplane_utils.ObjectLifecycleManagerProxy):
             actions = []
         bucket_allocator = self.bucket_allocators[prefix]
         bucket_id = bucket_allocator.get_new_id(
-            "Bucket ID for prefix %s and nexthop %s" % (str(prefix), nexthop),
+            "Bucket ID for prefix {} and nexthop {}".format(
+                str(prefix), nexthop),
             hint_value=nexthop.lb_consistent_hash_order
         )
         bucket = 'bucket=bucket_id=%d,%s' % (bucket_id,
@@ -882,9 +881,19 @@ class MPLSOVSDataplaneDriver(dp_drivers.DataplaneDriver):
                     help=("Be ready to receive VPN traffic as VXLAN, and to "
                           "preferrably send traffic as VXLAN when advertised "
                           "by the remote end")),
-        cfg.StrOpt("ovs_bridge", default="br-mpls", advanced=True),
-        cfg.IntOpt("input_table", default=0, advanced=True),
-        cfg.IntOpt("ovs_table_id_start", default=1, advanced=True),
+        cfg.StrOpt("ovs_bridge", default="br-mpls", advanced=True,
+                   help=("Name of the OVS bridge to use, this has to be the "
+                         "same as the tunneling bridge of the Neutron OVS "
+                         "agent.")),
+        cfg.IntOpt("input_table", default=0, advanced=True,
+                   help=("Specifies which OVS table will host the rules "
+                         "for traffic from VRFs")),
+        cfg.IntOpt("ovs_table_id_start", default=1, advanced=True,
+                   help=("The starting OVS table number to use for "
+                         "additional tables. The values for the encap-in "
+                         "and VRF tables are derived from this. "
+                         "NOTE: This must be different than input_table "
+                         "config option.")),
         cfg.StrOpt("gre_tunnel", default="mpls_gre", advanced=True,
                    help="OVS interface name for MPLS/GRE encap"),
         cfg.ListOpt("gre_tunnel_options", default=[],
@@ -894,7 +903,8 @@ class MPLSOVSDataplaneDriver(dp_drivers.DataplaneDriver):
                           ", ...') that will be added as OVS tunnel "
                           "interface options (e.g. 'options:packet_type="
                           "legacy_l3 options:...')")),
-        cfg.IntOpt("ovsbr_interfaces_mtu", advanced=True),
+        cfg.IntOpt("ovsbr_interfaces_mtu", advanced=True,
+                   help=("MTU used for OVS bridge interfaces.")),
         cfg.StrOpt("hash_method",
                    choices=["hash", "dp_hash"],
                    default="dp_hash",
@@ -902,8 +912,9 @@ class MPLSOVSDataplaneDriver(dp_drivers.DataplaneDriver):
                    help=("Can be used to control the OVS group bucket "
                          "selection method (mapped to ovs "
                          "'selection_method')")),
-        cfg.StrOpt("hash_method_param",
+        cfg.IntOpt("hash_method_param",
                    default=0,
+                   min=0, max=2**64 - 1,
                    advanced=True,
                    help=("Can be used to control the OVS group bucket "
                          "selection method (mapped to ovs "
@@ -915,9 +926,10 @@ class MPLSOVSDataplaneDriver(dp_drivers.DataplaneDriver):
     ]
 
     def __init__(self):
-        super(MPLSOVSDataplaneDriver, self).__init__()
+        super().__init__()
 
         config.set_default_root_helper()
+        config.setup_privsep()
 
         try:
             (o, _) = self._run_command("ovs-ofctl -V | head -1 |"
@@ -972,7 +984,7 @@ class MPLSOVSDataplaneDriver(dp_drivers.DataplaneDriver):
                                 self.config.input_table))
 
         self.encap_in_table = self.config.ovs_table_id_start
-        self.vrf_table = self.config.ovs_table_id_start+1
+        self.vrf_table = self.config.ovs_table_id_start + 1
 
         self.all_tables = {'incoming': self.input_table,
                            'vrf': self.vrf_table,
@@ -983,9 +995,12 @@ class MPLSOVSDataplaneDriver(dp_drivers.DataplaneDriver):
         self.vxlan_encap = self.config.vxlan_encap
 
         # check OVS version
+        ovs_release_version = versionutils.convert_version_to_tuple(
+            self.ovs_release)
+        required_ovs_version_tuple = versionutils.convert_version_to_tuple(
+            self.required_ovs_version)
         if (not self.vxlan_encap and
-                version.StrictVersion(self.ovs_release) <
-                version.StrictVersion(self.required_ovs_version)):
+                ovs_release_version < required_ovs_version_tuple):
             self.log.warning("%s requires at least OVS %s"
                              " (you are running %s)",
                              self.__class__.__name__,
@@ -1195,21 +1210,21 @@ class MPLSOVSDataplaneDriver(dp_drivers.DataplaneDriver):
         for (table_name, table_id) in self.all_tables.items():
             output.update({
                 "%s (%d)" % (table_name, table_id): self._run_command(
-                    "ovs-ofctl -O %s dump-flows --names %s '%s' %s" % (
+                    "ovs-ofctl -O {} dump-flows --names {} '{}' {}".format(
                         ovs_const.OPENFLOW15,
                         self.bridge.br_name,
                         dataplane_utils.join_s("table=%d" % table_id,
                                                cookie_spec),
                         OVS_DUMP_FLOW_FILTER),
                     run_as_root=True, shell=True
-                    )[0]
+                )[0]
             })
         return output
 
     def get_lg_ovs_ports(self, path_prefix):
         (output, _) = self._run_command(
-            "ovs-ofctl -O %s show %s |grep addr" % (ovs_const.OPENFLOW15,
-                                                    self.bridge.br_name),
+            "ovs-ofctl -O {} show {} |grep addr".format(ovs_const.OPENFLOW15,
+                                                        self.bridge.br_name),
             run_as_root=True,
             acceptable_return_codes=[0, 1],
             shell=True)
